# ASSESSES THE FACTORS ASSOCIATED WITH QUANTITY OF WILDLIFE OR FISH CONSUMED IN 2018
## Direct method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)

#focus on sensitive item
ind=which(dat$consumption_food_type=='wild_meat' & dat$questionnaire_type=="direct_only")
dat1=dat[ind,] 
unique(dat1$consumption_food_type)

#--------------------------------------------
#remove NA's from covariates and response variables
pred=c('cons_amount_2018','tot_days_2018')
covs=c('years_in_town_total','age','ppi','n_people','children')

nparam=length(covs)
apply(is.na(dat1[,c(covs,pred)]),2,sum)
k=apply(is.na(dat1[,c(covs,pred)]),1,sum)
table(k)
cond=k==0 
dat2=dat1[cond,]; dim(dat1); dim(dat2)

#remove observations for which cons_amount_2018=0
dat2$cons_amount_2018=dat2$cons_amount_2018*2 #to avoid non-integer values
cond1=!is.na(dat2$cons_amount_2018) & dat2$cons_amount_2018!=0
cond2=!is.na(dat2$cons_season)
ntown=max(dat2$town.id)

dat3=dat2[cond1 & cond2,]; dim(dat2); dim(dat3)
ntown=max(dat3$town.id)
#-------------------
#direct question, sensitive item
cond=dat3$consumption_food_type=='wild_meat'; 
dq.si=dat3[cond,]; dim(dq.si) 
xmat.dqsi=dq.si[,covs]
y.dqsi=dq.si$cons_amount_2018
size.dqsi=dq.si$tot_days_2018
y.dqsi.lfact=lfactorial(y.dqsi)
nobs.dqsi=length(y.dqsi)
k.dqsi=rep(1,nobs.dqsi)
town.id.dqsi=dq.si$town.id
#-------------------
#probability of answering sensitive question
dat1=list(xmat.dqsi=xmat.dqsi, y.dqsi=y.dqsi,nobs.dqsi=nobs.dqsi,town.id.dqsi=town.id.dqsi,k.dqsi=k.dqsi,size.dqsi=size.dqsi,y.dqsi.lfact=y.dqsi.lfact,
          nparam=nparam,ntowns=ntown)

#set parameters to track
params=c("gamma.si",'int.gamma.si','n.dqsi')

#initial values
inits <- function(){list(n.dqsi=1)} 

# MCMC settings 
n.iter <- 50000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 5000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='reg hurdle NB dq si.R',inits=inits,
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
setwd('C:\\results')
write.csv(pi.estim,'rate negbin dq_wild_meat.csv')

# get posterior distribution
gamma.si=model$sims.list$gamma.si; colnames(gamma.si)=covs
int.gamma=model$sims.list$int.gamma
write.csv(gamma.si, "posterior_rate_param_dq_wild_meat.csv")
write.csv(int.gamma, "posterior_rate_intercept_dq_wild_meat.csv")
write.csv(model$sims.list$n.dqsi, "posterior_rate_n_dq_wild_meat.csv")