# ASSESSES THE FACTORS ASSOCIATED WITH QUANTITY OF WILDLIFE OR FISH CONSUMED IN 2018
## Indirect method

rm(list=ls(all=TRUE))
library(jagsUI)
set.seed(2)

#bring data
setwd('C:\\Dataset')
socio=read.csv('socioeconomic_data_edited.csv',as.is=T)
cons=read.csv('consumption_data_wild meat.csv',as.is=T)

dat=merge(socio,cons); dim(socio); dim(cons); dim(dat)
unique(dat$consumption_food_type)

#focus on indirect question
## food items:
# acai_fish; pamonha_turtle; bacaba_wild_meat (wild_meat here refers to mammals and birds only)

ind=which(dat$consumption_food_type%in%c('bacaba','bacaba_wild_meat'))
dat1=dat[ind,] 
unique(dat1$consumption_food_type)

#--------------------------------------------
#remove NA's from covariates and response variables
pred=c('cons_amount_2018','tot_days_2018')
covs=c('years_in_town_total','age','ppi','n_people','children')

nparam=length(covs)
apply(is.na(dat1[,c(covs,pred)]),2,sum)
k=apply(is.na(dat1[,c(covs,pred)]),1,sum)
table(k)
cond=k==0 
dat2=dat1[cond,]; dim(dat1); dim(dat2)

#remove observations for which cons_amount_2018=0
dat2$cons_amount_2018=dat2$cons_amount_2018*2 #to avoid non-integer values
cond1=!is.na(dat2$cons_amount_2018) & dat2$cons_amount_2018!=0
cond2=!is.na(dat2$cons_season)
ntown=max(dat2$town.id)

dat3=dat2[cond1 & cond2,]; dim(dat2); dim(dat3)
ntown=max(dat3$town.id)
#-------------------
#direct question, non-sensitive item
cond=dat3$consumption_food_type=='bacaba'; 
ns=dat3[cond,]; dim(ns) 
xmat.ns=ns[,covs]
y.ns=ns$cons_amount_2018
size.ns=ns$tot_days_2018
y.ns.lfact=lfactorial(y.ns)
nobs.ns=length(y.ns)
k.ns=rep(1,nobs.ns)
town.id.ns=ns$town.id
#-------------------
#indirect question (iq)
cond=dat3$consumption_food_type=='bacaba_wild_meat'; 
iq=dat3[cond,]; dim(iq) 
xmat.iq=iq[,covs]
y.iq=iq$cons_amount_2018
size.iq=iq$tot_days_2018
y.iq.lfact=lfactorial(y.iq)
nobs.iq=length(y.iq)
k.iq=rep(1,nobs.iq)
town.id.iq=iq$town.id
#-------------------
#data for jags
pi.s=4/6
dat1=list(xmat.ns=xmat.ns,y.ns=y.ns,nobs.ns=nobs.ns,town.id.ns=town.id.ns,k.ns=k.ns,size.ns=size.ns,y.ns.lfact=y.ns.lfact,
          xmat.iq=xmat.iq,y.iq=y.iq,nobs.iq=nobs.iq,town.id.iq=town.id.iq,k.iq=k.iq,size.iq=size.iq,y.iq.lfact=y.iq.lfact,
          nparam=nparam,ntowns=ntown,pi.s=pi.s)

#set parameters to track
params=c("betas.ns",'betas.si','int.ns','int.si','n.all')

#initial values
inits <- function(){list(n.all=1)} 

# MCMC settings 
n.iter <- 5000
n.thin <- 10  
n.burnin <- n.iter/2
n.chains <- 3
n.adapt<- 1000  

#fit the model
setwd('C:\\models_jags')
model=jags(model.file='reg hurdle NB iq.R',inits=inits,
           parameters.to.save=params,data=dat1,
           n.chains=n.chains,n.burnin=n.burnin,n.adapt=n.adapt,n.iter=n.iter,n.thin=n.thin,
           DIC=TRUE,parallel=TRUE)
summary(model)

#look at results
setwd('C:\\results')
res=model$summary
pi.estim=as.data.frame(res[,c('mean','2.5%','50%','97.5%','Rhat','overlap0')])

#export summary of results
write.csv(pi.estim,'rate negbin iq_wild meat.csv')
# get posterior distribution

# get posterior distribution
betas.si=model$sims.list$betas.si; colnames(betas.si)=covs
int.si=model$sims.list$int.si
write.csv(betas.si, "posterior_rate_param_iq_wild meat.csv")
write.csv(int.si, "posterior_rate_intercept_iq_wild meat.csv")
write.csv(model$sims.list$n.all, "posterior_rate_n_iq_wild meat.csv")